@@ -3,7 +3,7 @@ package sqlite
 import (
 	"testing"
 
-	"github.com/mickael-menu/zk/internal/util/test/assert"
+	"github.com/zk-org/zk/internal/util/test/assert"
 )
 
 func TestMetadataDAOGetUnknown(t *testing.T) {
